@@ -26,9 +26,13 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: defs.h,v 2.38 1996/05/21 03:20:55 jrs Exp $
+ *	$Id: defs.h,v 1.3 1999/04/18 22:50:50 wichert Exp $
  */
 
+#ifdef linux
+#include <features.h>
+#endif
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -67,13 +71,30 @@
 #include <stddef.h>
 #endif /* STDC_HEADERS */
 
+#if defined(LINUX) && defined(SPARC)
+#define LINUXSPARC
+#endif /* LINUX && SPARC */
+
 #ifdef SVR4
 #include <sys/procfs.h>
 #else /* !SVR4 */
+#if defined(LINUXSPARC) && defined(__GLIBC__)
+#include <sys/ptrace.h>
+#else
 /* Work around awkward prototype in ptrace.h. */
 #define ptrace xptrace
 #include <sys/ptrace.h>
 #undef ptrace
+#ifdef POWERPC
+#define __KERNEL__
+#include <asm/ptrace.h>
+#undef __KERNEL__
+/* TEMP */
+#define UESP	PT_R1
+#define EIP	PT_NIP
+#define EAX	PT_R3
+#define ORIG_EAX PT_ORIG_R3
+#endif
 #ifdef __STDC__
 #ifdef LINUX
 extern long ptrace(int, int, char *, long);
@@ -83,11 +104,14 @@ extern int ptrace(int, int, char *, int, ...);
 #else /* !__STDC__ */
 extern int ptrace();
 #endif /* !__STDC__ */
+#endif /* !LINUXSPARC */
 #endif /* !SVR4 */
 
 #ifdef LINUX
+#if !defined(__GLIBC__)
 #define	PTRACE_PEEKUSER	PTRACE_PEEKUSR
 #define	PTRACE_POKEUSER	PTRACE_POKEUSR
+#endif
 #ifdef ALPHA
 #define REG_R0 0
 #define REG_A0 16
@@ -100,12 +124,12 @@ extern int ptrace();
 #define SUPPORTED_PERSONALITIES 1
 #define DEFAULT_PERSONALITY 0
 
-#ifdef LINUX
-#ifdef SPARC
-#undef SUPPORTED_PERSONALITIES
-#define SUPPORTED_PERSONALITIES 3
-#endif /* SPARC */
-#endif /* LINUX */
+#ifdef LINUXSPARC
+#include <linux/a.out.h>
+#include <asm/psr.h>
+#undef  SUPPORTED_PERSONALITIES
+#define SUPPORTED_PERSONALITIES 2
+#endif /* LINUXSPARC */
 
 /* Trace Control Block */
 struct tcb {
@@ -147,7 +171,7 @@ struct tcb {
 #define TCB_FOLLOWFORK	00400	/* Process should have forks followed */
 #define TCB_REPRINT	01000	/* We should reprint this syscall on exit */
 #ifdef LINUX
-#ifdef ALPHA
+#if defined(ALPHA) || defined(SPARC) || defined(POWERPC)
 #define TCB_WAITEXECVE	02000	/* ignore SIGTRAP after exceve */
 #endif /* ALPHA */
 #endif /* LINUX */
@@ -247,6 +271,7 @@ extern int clearbpt P((struct tcb *));
 extern int setbpt P((struct tcb *));
 extern int sigishandled P((struct tcb *, int));
 extern void printcall P((struct tcb *));
+extern char *signame P((int));
 extern void printsignal P((int));
 extern void printleader P((struct tcb *));
 extern void printtrailer P((struct tcb *));
@@ -278,7 +303,7 @@ extern void tv_div P((struct timeval *, struct timeval *, int));
 #ifdef SUNOS4
 extern int fixvfork P((struct tcb *));
 #endif
-#ifndef LINUX
+#if !(defined(LINUX) && !defined(SPARC))
 extern long getrval2 P((struct tcb *));
 #endif
 #ifdef SVR4
@@ -343,14 +368,14 @@ extern int nioctlents0;
 extern char *signalent0[];
 extern int nsignals0;
 
-#if SUPPORTED_PERSONALITES >= 2
+#if SUPPORTED_PERSONALITIES >= 2
 extern struct ioctlent ioctlent1[];
 extern int nioctlents1;
 extern char *signalent1[];
 extern int nsignals1;
 #endif /* SUPPORTED_PERSONALITIES >= 2 */
 
-#if SUPPORTED_PERSONALITES >= 3
+#if SUPPORTED_PERSONALITIES >= 3
 extern struct ioctlent ioctlent2[];
 extern int nioctlents2;
 extern char *signalent2[];
