@@ -26,15 +26,48 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: file.c,v 1.10 1999/04/21 15:57:38 wichert Exp $
+ *	$Id: file.c,v 1.13 1999/06/03 14:21:07 wichert Exp $
  */
 
 #include "defs.h"
 
 #include <dirent.h>
+#ifdef linux
+#define dirent kernel_dirent
+#include <linux/types.h>
+#include <linux/dirent.h>
+#undef dirent
+#else
+#define kernel_dirent dirent
+#endif
 
 #ifdef linux
-#  include <asm/stat.h>
+#  ifdef LINUXSPARC
+struct stat {
+	unsigned short	st_dev;
+	unsigned int	st_ino;
+	unsigned short	st_mode;
+	short		st_nlink;
+	unsigned short	st_uid;
+	unsigned short	st_gid;
+	unsigned short	st_rdev;
+	unsigned int	st_size;
+	int		st_atime;
+	unsigned int	__unused1;
+	int		st_mtime;
+	unsigned int	__unused2;
+	int		st_ctime;
+	unsigned int	__unused3;
+	int		st_blksize;
+	int		st_blocks;
+	unsigned int	__unused4[2];
+};
+#    define stat kernel_stat
+#    include <asm/stat.h>
+#    undef stat
+#  else
+#    include <asm/stat.h>
+#  endif
 #  define stat libc_stat
 #  include <sys/stat.h>
 #  undef stat
@@ -283,21 +316,19 @@ struct tcb *tcp;
     if (entering(tcp)) {
 	if (tcp->u_arg[4] == SEEK_SET)
 	    tprintf("%ld, %llu, ", tcp->u_arg[0],
-		    (((unsigned long long int) tcp->u_arg[1]) << 32
-		     | (unsigned long) tcp->u_arg[2]));
+		    (((long long int) tcp->u_arg[1]) << 32
+		     | (unsigned long long) tcp->u_arg[2]));
 	else
 	    tprintf("%ld, %lld, ", tcp->u_arg[0],
 		    (((long long int) tcp->u_arg[1]) << 32
-		     | (unsigned long) tcp->u_arg[2]));
+		     | (unsigned long long) tcp->u_arg[2]));
     }
     else {
-	if (syserror(tcp))
+	long long int off;
+	if (syserror(tcp) || umove(tcp, tcp->u_arg[3], &off) < 0)
 	    tprintf("%#lx, ", tcp->u_arg[3]);
-	else {
-	    long long int off;
-	    umove(tcp, tcp->u_arg[3], &off);
-	    tprintf("{%lld}, ", off);
-	}
+	else
+	    tprintf("[%llu], ", off);
 	printxval(whence, tcp->u_arg[4], "SEEK_???");
     }
     return 0;
@@ -764,7 +795,8 @@ static struct xlat fsmagic[] = {
 	{ 0x9660,	"ISOFS_SUPER_MAGIC"	},
 	{ 0x137f,	"MINIX_SUPER_MAGIC"	},
 	{ 0x138f,	"MINIX_SUPER_MAGIC2"	},
-	{ 0x2468,	"NEW_MINIX_SUPER_MAGIC"	},
+	{ 0x2468,	"MINIX2_SUPER_MAGIC"	},
+	{ 0x2478,	"MINIX2_SUPER_MAGIC2"	},
 	{ 0x4d44,	"MSDOS_SUPER_MAGIC"	},
 	{ 0x6969,	"NFS_SUPER_MAGIC"	},
 	{ 0x9fa0,	"PROC_SUPER_MAGIC"	},
@@ -814,7 +846,7 @@ long addr;
 	tprintf("{f_type=%s, f_fbsize=%u, f_blocks=%u, f_bfree=%u, ",
 		sprintfstype(statbuf.f_type),
 		statbuf.f_bsize, statbuf.f_blocks, statbuf.f_bfree);
-	tprintf("f_bavail=%u, f_files=%u, f_ffree=%u, f_namelen=%u}",
+	tprintf("f_bavail=%u, f_files=%u, f_ffree=%u, f_namelen=%u",
 		statbuf.f_bavail,statbuf.f_files, statbuf.f_ffree, statbuf.f_namelen);
 #else /* !ALPHA */
 	tprintf("{f_type=%s, f_bsize=%lu, f_blocks=%lu, f_bfree=%lu, ",
@@ -826,7 +858,7 @@ long addr;
 		(unsigned long)statbuf.f_files,
 		(unsigned long)statbuf.f_ffree);
 #ifdef linux
-	tprintf(", f_namelen=%lu}", (unsigned long)statbuf.f_namelen);
+	tprintf(", f_namelen=%lu", (unsigned long)statbuf.f_namelen);
 #endif /* linux */
 #endif /* !ALPHA */
 	tprintf("}");
@@ -1248,7 +1280,7 @@ struct tcb *tcp;
 	if (!abbrev(tcp))
 		tprintf("{");
 	for (i = 0; i < len;) {
-		struct dirent *d = (struct dirent *) &buf[i];
+		struct kernel_dirent *d = (struct kernel_dirent *) &buf[i];
 #ifdef linux
 		if (!abbrev(tcp)) {
 			tprintf("%s{d_ino=%lu, d_off=%lu, ",
@@ -1296,7 +1328,7 @@ struct tcb *tcp;
 	if (syserror(tcp))
 	    tprintf("%#lx", tcp->u_arg[0]);
 	else
-	    printstr(tcp, tcp->u_arg[0], tcp->u_arg[1]);
+	    printpathn(tcp, tcp->u_arg[0], tcp->u_rval - 1);
 	tprintf(", %lu", tcp->u_arg[1]);
     }
     return 0;
