@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.h,v 1.1.1.1 1999/02/19 00:23:00 wichert Exp $
+ *	$Id: syscall.h,v 1.3 1999/06/03 14:21:07 wichert Exp $
  */
 
 #include "dummy.h"
@@ -36,7 +36,7 @@ int sys_setup(), sys_exit(), sys_fork(), sys_read(), sys_write();
 int sys_open(), sys_close(), sys_waitpid(), sys_creat(), sys_link();
 int sys_unlink(), sys_execve(), sys_chdir(), sys_time(), sys_mknod();
 int sys_chmod(), sys_chown(), sys_break(), sys_oldstat();
-int sys_lseek(), sys_getpid(), sys_mount(), sys_umount();
+int sys_lseek(), sys_getpid(), sys_mount(), sys_umount(), sys_umount2();
 int sys_setuid(), sys_getuid(), sys_stime(), sys_ptrace();
 int sys_alarm(), sys_oldfstat(), sys_pause(), sys_utime();
 int sys_stty(), sys_gtty(), sys_access(), sys_nice(), sys_ftime();
@@ -81,6 +81,7 @@ int sys_getresuid(), sys_getresgid(), sys_pread(), sys_pwrite(), sys_getcwd();
 int sys_sigaltstack(), sys_rt_sigprocmask(), sys_rt_sigaction();
 int sys_rt_sigpending(), sys_rt_sigsuspend(), sys_rt_sigqueueinfo();
 int sys_rt_sigtimedwait(), sys_prctl(), sys_poll(), sys_vfork();
+int sys_sendfile();
 
 
 /* sys_socketcall subcalls */
@@ -153,3 +154,6 @@ int osf_statfs(), osf_fstatfs(), sys_getpagesize(), sys_madvise();
 int sys_setpgrp(), sys_gethostname(), sys_getdtablesize(), sys_utimes();
 int sys_capget(), sys_capset();
 
+#ifdef M68K
+int sys_cacheflush();
+#endif
