@@ -26,16 +26,15 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: mem.c,v 1.4 1999/04/21 15:57:38 wichert Exp $
+ *	$Id: mem.c,v 1.5 1999/05/09 00:29:58 wichert Exp $
  */
 
 #include "defs.h"
 
-#ifdef LINUXSPARC
+#ifdef LINUX
 #include <linux/mman.h>
-#else
-#include <sys/mman.h>
 #endif
+#include <sys/mman.h>
 
 #if defined(LINUX) && defined(__i386__)
 #include <asm/ldt.h>
@@ -170,6 +169,26 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef LINUX
+
+static struct xlat mremap_flags[] = {
+	{ MREMAP_MAYMOVE, "MREMAP_MAYMOVE" },
+};
+
+int
+sys_mremap(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp)) {
+		tprintf("%#lx, %lu, %lu, ", tcp->u_arg[0], tcp->u_arg[1],
+			tcp->u_arg[2]);
+		printflags(mremap_flags, tcp->u_arg[3]);
+	}
+	return RVAL_HEX;
+}
+
+#endif /* LINUX */
+
 #ifdef MS_ASYNC
 
 static struct xlat mctl_sync[] = {
