@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: strace.c,v 1.2 1999/03/29 23:23:13 nate Exp $
+ *	$Id: strace.c,v 1.3 1999/06/03 14:21:07 wichert Exp $
  */
 
 #include "defs.h"
@@ -820,6 +820,10 @@ int sig;
 	 * before detaching.  Arghh.  We go through hoops
 	 * to make a clean break of things.
 	 */
+#if defined(SPARC)
+#undef PTRACE_DETACH
+#define PTRACE_DETACH PTRACE_SUNDETACH
+#endif
 	if ((error = ptrace(PTRACE_DETACH, tcp->pid, (char *) 1, sig)) == 0) {
 		/* On a clear day, you can see forever. */
 	}
