@@ -24,7 +24,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: stream.c,v 1.2 1999/04/18 23:30:29 wichert Exp $
+ *	$Id: stream.c,v 1.3 1999/05/09 00:29:59 wichert Exp $
  */
 
 #include "defs.h"
@@ -78,7 +78,7 @@ int getting;
 		if (getting)
 			tprintf("maxlen=%d, ", sbp->maxlen);
 		tprintf("len=%d, buf=", sbp->len);
-		printstr(tcp, (int) sbp->buf, sbp->len);
+		printstr(tcp, (unsigned long) sbp->buf, sbp->len);
 		tprintf("}");
 	}
 }
