@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.c,v 1.4 1999/04/18 22:50:51 wichert Exp $
+ *	$Id: syscall.c,v 1.6 1999/06/03 14:21:07 wichert Exp $
  */
 
 #include "defs.h"
@@ -41,7 +41,7 @@
 # include <sys/reg.h>
 #endif
 
-#ifdef LINUX
+#if defined LINUX && __GLIBC__ < 2
 #include <linux/ptrace.h>
 #endif /* LINUX */
 
@@ -653,6 +653,10 @@ struct tcb *tcp;
 			/* Linux/SPARC syscall trap. */
 			set_personality(0);
 			break;
+		case 0x91d0206d:
+			/* Linux/SPARC64 syscall trap. */
+			fprintf(stderr,"syscall: Linux/SPARC64 not supported yet\n");
+			return -1;
 		case 0x91d02000:
 			/* SunOS syscall trap. (pers 1) */
 			fprintf(stderr,"syscall: SunOS no support\n");
