@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: util.c,v 1.3 1999/03/17 00:42:25 wichert Exp $
+ *	$Id: util.c,v 1.6 1999/06/03 14:21:07 wichert Exp $
  */
 
 #include "defs.h"
@@ -44,9 +44,15 @@
 # define PTRACE_PEEKUSR PTRACE_PEEKUSER
 #endif
 #ifdef LINUX
+#if !defined(__GLIBC__) || defined(SPARC)
 #include <linux/ptrace.h>
+#endif
 #endif /* LINUX */
 
+#ifdef HAVE_SYS_PTRACE_H
+#include <sys/ptrace.h>
+#endif
+
 #ifdef SUNOS4_KERNEL_ARCH_KLUDGE
 #include <sys/utsname.h>
 #endif /* SUNOS4_KERNEL_ARCH_KLUDGE */
@@ -356,7 +362,7 @@ int len;
 			return;
 		}
 	}
-	outend = outstr + max_strlen;
+	outend = outstr + max_strlen * 2 - 10;
 	if (len < 0) {
 		n = max_strlen;
 		if (umovestr(tcp, addr, n, (char *) str) < 0) {
@@ -643,7 +649,7 @@ long addr;
 int len;
 char *laddr;
 {
-#ifdef SRVR4
+#ifdef SVR4
 	return umoven(tcp, addr, len, laddr);
 #else /* !SVR4 */
 	int started = 0;
